API
###

Main Class
==========

.. automodule:: gptide.gpscipy
    :members:
    :inherited-members:
    :special-members: __call__, __init__

Parent Class
============

.. automodule:: gptide.gp
    :members:
    
Covariance functions
====================

.. automodule:: gptide.cov
    :members:
    
Inference
=========

.. automodule:: gptide.mcmc
    :members:

    
.. automodule:: gptide.mle
    :members:



